---
title: 'application:maintenance'
url: 'https://docs.danami.com/sentinel/command-line-interface/application/application-maintenance'
markdown: 'https://docs.danami.com/sentinel/command-line-interface/application/application-maintenance.md'
date: '2026-09-22'
description: 'Configure the panel maintenance settings. sentinel --task=application:maintenance Option Value Default Description --prune_action_logs <digit> 90 A nightly task to prune action logs older than this number of days. --prune_application_logs <digit> 90 A nightly task to prune applicatio…'
taxonomy:
  category:
    - docs
---

[](#)  [ Basics ](https://docs.danami.com/sentinel/)     [ Command Line Interface ](https://docs.danami.com/sentinel/command-line-interface)      Application       application:maintenance    

# application:maintenance

Configure the panel maintenance settings.

```
sentinel --task=application:maintenance
```

| Option | Value | Default | Description |
|---|---|---|---|
| `--prune_action_logs` | <digit> | 90 | A nightly task to prune action logs older than this number of days. |
| `--prune_application_logs` | <digit> | 90 | A nightly task to prune application debug logs older than this number of days. |
| `--prune_domain_monitor` | <digit> | 90 | A nightly task to prune domain monitoring logs older than this number of days. |
| `--default` | <yes> |  | Reset all settings to their default values. |
| `--default_option` | <option> |  | Reset a specific setting to its default value. |

## Examples

```
// set prune_domain_monitor to every 60 days
sentinel --task=application:maintenance --prune_domain_monitor=60

// reset the prune_domain_monitor back to its default value
sentinel --task=application:maintenance --default_option=prune_domain_monitor

// reset all settings to their default values
sentinel --task=application:maintenance --default=yes
```

 [ ](https://docs.danami.com/sentinel/command-line-interface/application/application-geolocation) [](https://docs.danami.com/sentinel/command-line-interface/application/application-maintenance-database)

---

## Navigation

- Previous: [application:license](https://docs.danami.com/sentinel/command-line-interface/application/application-license.md)
- Next: [application:maintenance:database](https://docs.danami.com/sentinel/command-line-interface/application/application-maintenance-database.md)
